==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/FhirServiceImportConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.FhirServiceImportConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Import operation configuration information
 * @property enabled If the import operation is enabled.
 * @property initialImportMode If the FHIR service is in InitialImportMode.
 * @property integrationDataStore The name of the default integration storage account.
 */
public data class FhirServiceImportConfigurationArgs(
    public val enabled: Output<Boolean>? = null,
    public val initialImportMode: Output<Boolean>? = null,
    public val integrationDataStore: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.FhirServiceImportConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceImportConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceImportConfigurationArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .initialImportMode(initialImportMode?.applyValue({ args0 -> args0 }))
            .integrationDataStore(integrationDataStore?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FhirServiceImportConfigurationArgs].
 */
@PulumiTagMarker
public class FhirServiceImportConfigurationArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var initialImportMode: Output<Boolean>? = null

    private var integrationDataStore: Output<String>? = null

    /**
     * @param value If the import operation is enabled.
     */
    @JvmName("pvajvnhrhdawnodb")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value If the FHIR service is in InitialImportMode.
     */
    @JvmName("dyiejsubwavhrrij")
    public suspend fun initialImportMode(`value`: Output<Boolean>) {
        this.initialImportMode = value
    }

    /**
     * @param value The name of the default integration storage account.
     */
    @JvmName("xsplljnfbefxgfvv")
    public suspend fun integrationDataStore(`value`: Output<String>) {
        this.integrationDataStore = value
    }

    /**
     * @param value If the import operation is enabled.
     */
    @JvmName("vhjlxqdpotjuhrgb")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value If the FHIR service is in InitialImportMode.
     */
    @JvmName("ujbwpqoaqqdkpuge")
    public suspend fun initialImportMode(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.initialImportMode = mapped
    }

    /**
     * @param value The name of the default integration storage account.
     */
    @JvmName("ankfokvaoyimoqbw")
    public suspend fun integrationDataStore(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.integrationDataStore = mapped
    }

    internal fun build(): FhirServiceImportConfigurationArgs = FhirServiceImportConfigurationArgs(
        enabled = enabled,
        initialImportMode = initialImportMode,
        integrationDataStore = integrationDataStore,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/FhirServiceImportConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.FhirServiceImportConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Import operation configuration information
 * @property enabled If the import operation is enabled.
 * @property initialImportMode If the FHIR service is in InitialImportMode.
 * @property integrationDataStore The name of the default integration storage account.
 */
public data class FhirServiceImportConfigurationArgs(
    public val enabled: Output<Boolean>? = null,
    public val initialImportMode: Output<Boolean>? = null,
    public val integrationDataStore: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.FhirServiceImportConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceImportConfigurationArgs =
        com.pulumi.azurenative.healthcareapis.inputs.FhirServiceImportConfigurationArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 }))
            .initialImportMode(initialImportMode?.applyValue({ args0 -> args0 }))
            .integrationDataStore(integrationDataStore?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FhirServiceImportConfigurationArgs].
 */
@PulumiTagMarker
public class FhirServiceImportConfigurationArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    private var initialImportMode: Output<Boolean>? = null

    private var integrationDataStore: Output<String>? = null

    /**
     * @param value If the import operation is enabled.
     */
    @JvmName("yslcetatrkgeaptm")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value If the FHIR service is in InitialImportMode.
     */
    @JvmName("uocgflccijkthldj")
    public suspend fun initialImportMode(`value`: Output<Boolean>) {
        this.initialImportMode = value
    }

    /**
     * @param value The name of the default integration storage account.
     */
    @JvmName("iocbuyroapttqnmn")
    public suspend fun integrationDataStore(`value`: Output<String>) {
        this.integrationDataStore = value
    }

    /**
     * @param value If the import operation is enabled.
     */
    @JvmName("mnepaibcheygqhrj")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    /**
     * @param value If the FHIR service is in InitialImportMode.
     */
    @JvmName("mchrvmuroayyyjwu")
    public suspend fun initialImportMode(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.initialImportMode = mapped
    }

    /**
     * @param value The name of the default integration storage account.
     */
    @JvmName("yvokqutfutgbtcor")
    public suspend fun integrationDataStore(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.integrationDataStore = mapped
    }

    internal fun build(): FhirServiceImportConfigurationArgs = FhirServiceImportConfigurationArgs(
        enabled = enabled,
        initialImportMode = initialImportMode,
        integrationDataStore = integrationDataStore,
    )
}
